@@ -1016,7 +1016,7 @@ class PartitionDistributive(Distributive):
         'ntfs': FormatNtfs,
         'uefi': FormatUefi,
         'btrfs': FormatBtrfs,
-        'btrfs-comp': FormatBtrfsCompressed,
+        'btrfs-compress': FormatBtrfsCompressed,
         'swap': FormatSwap
     }
 
@@ -1135,7 +1135,7 @@ class PartitionDistributive(Distributive):
                 realMountPoint = None
                 if fileSystem != "swap":
                     realMountPoint = pathJoin(mdirectory, mountPoint)
-                    mapFS = {'btrfs-comp': 'btrfs'}
+                    mapFS = {'btrfs-compress': 'btrfs'}
                     self._mountPartition(
                         dev, realMountPoint,
                         "-t %s" % mapFS.get(fileSystem,fileSystem))
@@ -1172,7 +1172,7 @@ class PartitionDistributive(Distributive):
         # if has separate /boot partition
         bootmp = ["/boot", "/"]
         purpose_map = {"/boot": "boot",
-                       "/var/calculate","calculate",
+                       "/var/calculate": "calculate",
                        "/": "root"}
         # format all get partition
         for fileSystem, dev, newID, mp in formatPartitions:
