@@ -136,7 +136,7 @@ class ClSetupThemesAction(ClSetupSystemAction):
     ]
     templateTaskMessage = __("The themes are being configured")
     successMessage = __("Themes configured!")
-    failedMessage = __("Failed to configure themes!")
+    failedMessage = __("Theme configuration failed!")
 
 
 class ClSetupLocaleAction(ClSetupSystemAction):
