@@ -356,9 +356,12 @@ class VariableOsInstallFbResolution(ResolutionVariable):
         kms = self.Get('install.os_x11_kms_video_drv')
         return drv in kms
 
+    def using_uefi(self):
+        return self.GetBool('install.os_install_uefi_set')
+
     def get(self):
         x11res = self.Get('os_install_x11_resolution')
-        if self.using_kms():
+        if self.using_kms() or self.using_uefi():
             return x11res
         hwinfo = device.Hwinfo()
         try:
