@@ -584,7 +584,7 @@ class VariableOsDiskFormat(ReadonlyVariable):
             if fs == "btrfs":
                 try:
                     if Btrfs(dev).compression != "":   
-                        return "btrfs-comp"
+                        return "btrfs-compress"
                 except BtrfsError:
                     pass
             return fs
