@@ -575,7 +575,8 @@ class VariableClTarget(ReadonlyVariable):
                 rootLabel=rootLabel,
                 isFormat=self.isTrue(isFormat),
                 systemId=systemId,
-                partitionTable=partTable)
+                partitionTable=partTable,
+                compression=self.Get('os_install_btrfs_compression'))
         multiPartition = None
         diskData = self.Select(listVars,
                                where='os_install_disk_mount',
